@@ -64,10 +64,10 @@ def validate_project_name(project_name):
             )
 
 
-def recuse_object(d: dict):
+def recurse_object(d: dict):
     for k, v in d.items():
         if isinstance(v, dict):
-            yield from recuse_object(v)
+            yield from recurse_object(v)
         elif v.startswith("http"):
             yield (v, v.split("?")[0].split("/")[-1])
 
